struct Args {
wave_file: Option<String>,
command_file: Option<Utf8PathBuf>,
script: Option<Utf8PathBuf>,
state_file: Option<Utf8PathBuf>,
wcp_initiate: Option<u16>,
command: Option<Commands>,
}Fields
wave_file: Option<String>Waveform file in VCD, FST, or GHW format.
command_file: Option<Utf8PathBuf>Path to a file containing ‘commands’ to run after a waveform has been loaded.
The commands are the same as those used in the command line interface inside the program.
Commands are separated by lines or ;. Empty lines are ignored. Line comments starting with
# are supported
NOTE: This feature is not permanent, it will be removed once a solid scripting system
is implemented.
script: Option<Utf8PathBuf>Alias for –command_file to support VUnit
state_file: Option<Utf8PathBuf>Load previously saved state file
wcp_initiate: Option<u16>Port for WCP to connect to
command: Option<Commands>Implementations
Sourceimpl Args
impl Args
pub fn command_file(&self) -> Option<&Utf8PathBuf>